#ifndef _REGEX_H
#define _REGEX_H

#include <gc/gc.h>
#include <pcre.h>
#include "Heap.h"

class Array;

class Match : public gc 
{
public:
    bool matched;
    Array* matches;

    wchar_t* before;
    wchar_t* after;
};

extern "C" {

void* re_compile(wchar_t* pattern, kint flagcode);
void* re_match(void* pc, wchar_t* str);

Array* getmatches(void* mo);
bool matched(void* mo);
wchar_t* getBefore(void* mo);
wchar_t* getAfter(void* mo);

}

#endif
